@@ -3,8 +3,11 @@ use std::convert::TryInto;
 use mit_commit::CommitMessage;
 use thiserror::Error;
 
-use crate::model::{Lints, Problem};
-use crate::{checks, model};
+use crate::{
+    checks,
+    model,
+    model::{Lints, Problem},
+};
 
 /// The lints that are supported
 #[derive(Debug, Eq, PartialEq, Copy, Clone, Hash, Ord, PartialOrd)]
@@ -22,6 +25,7 @@ pub enum Lint {
     NotEmojiLog,
 }
 
+/// The prefix we put in front of the lint when serialising
 pub const CONFIG_KEY_PREFIX: &str = "mit.lint";
 
 impl std::convert::TryFrom<&str> for Lint {
@@ -51,6 +55,7 @@ impl From<Lint> for &str {
 }
 
 impl Lint {
+    /// Get an lint's unique name
     #[must_use]
     pub fn name(self) -> &'static str {
         match self {
@@ -72,6 +77,7 @@ impl Lint {
 }
 
 lazy_static! {
+    /// All the available lints
     static ref ALL_LINTS: [Lint; 11] = [
         Lint::DuplicatedTrailers,
         Lint::PivotalTrackerIdMissing,
@@ -85,6 +91,7 @@ lazy_static! {
         Lint::NotConventionalCommit,
         Lint::NotEmojiLog,
     ];
+    /// The ones that are enabled by default
     static ref DEFAULT_ENABLED_LINTS: [Lint; 4] = [
         Lint::DuplicatedTrailers,
         Lint::SubjectNotSeparateFromBody,
@@ -93,20 +100,56 @@ lazy_static! {
     ];
 }
 impl Lint {
+    /// Iterator over all the lints
+    ///
+    /// # Examples
+    ///
+    /// ``` rust
+    /// use mit_lint::Lint;
+    /// assert!(Lint::iterator().next().is_some())
+    /// ```
     pub fn iterator() -> impl Iterator<Item = Lint> {
         ALL_LINTS.iter().copied()
     }
 
+    /// Check if a lint is enabled by default
+    ///
+    /// # Examples
+    ///
+    /// ``` rust
+    /// use mit_lint::Lint;
+    /// assert!(Lint::SubjectNotSeparateFromBody.enabled_by_default());
+    /// assert!(!Lint::NotConventionalCommit.enabled_by_default());
+    /// ```
     #[must_use]
     pub fn enabled_by_default(self) -> bool {
         DEFAULT_ENABLED_LINTS.contains(&self)
     }
 
+    /// Get a key suitable for a configuration document
+    ///
+    /// # Examples
+    ///
+    /// ``` rust
+    /// use mit_lint::Lint;
+    /// assert_eq!(Lint::SubjectNotSeparateFromBody.config_key(), "mit.lint.subject-not-separated-from-body");
+    /// ```
     #[must_use]
     pub fn config_key(self) -> String {
         format!("{}.{}", CONFIG_KEY_PREFIX, self)
     }
 
+    /// Run this lint on a commit message
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use mit_commit::CommitMessage;
+    /// use mit_lint::Lint;
+    /// let actual =
+    ///     Lint::NotConventionalCommit.lint(&CommitMessage::from("An example commit message"));
+    /// assert!(actual.is_some());
+    /// ```
     #[must_use]
     pub fn lint(self, commit_message: &CommitMessage) -> Option<Problem> {
         match self {
@@ -136,6 +179,17 @@ impl Lint {
 
     /// Try and convert a list of names into lints
     ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use mit_lint::Lint;
+    /// let actual = Lint::from_names(vec!["not-emoji-log", "body-wider-than-72-characters"]);
+    /// assert_eq!(
+    ///     actual.unwrap(),
+    ///     vec![Lint::BodyWiderThan72Characters, Lint::NotEmojiLog]
+    /// );
+    /// ```
+    ///
     /// # Errors
     /// If the lint does not exist
     pub fn from_names(names: Vec<&str>) -> Result<Vec<Lint>, model::lints::Error> {
@@ -207,6 +261,7 @@ impl std::fmt::Display for Lint {
     }
 }
 
+/// Errors
 #[derive(Error, Debug)]
 pub enum Error {
     #[error("Lint not found: {0}")]
